@@ -163,9 +163,9 @@ class FileOutput(object):
     def __init__(self, file_path, compressed = False):
         self.file_path = file_path
 
-        self.compressed = compressed
+        self.compressed_output = compressed
 
-        if self.compressed:
+        if self.compressed_output:
             self.file_pointer = gzip.open(file_path, 'w')
         else:
             self.file_pointer = open(file_path, 'w')
@@ -188,10 +188,16 @@ class FastQOutput(FileOutput):
         super(FastQOutput, self).__init__(file_path, compressed)
 
     def store_entry(self, e):
-        self.file_pointer.write('@' + e.header_line + '\n')
-        self.file_pointer.write(e.sequence + '\n')
-        self.file_pointer.write('+' + e.optional + '\n')
-        self.file_pointer.write(e.qual_scores + '\n')
+        if self.compressed_output:
+            self.file_pointer.write(('@' + e.header_line + '\n').encode())
+            self.file_pointer.write((e.sequence + '\n').encode())
+            self.file_pointer.write(('+' + e.optional + '\n').encode())
+            self.file_pointer.write((e.qual_scores + '\n').encode())
+        else:
+            self.file_pointer.write('@' + e.header_line + '\n')
+            self.file_pointer.write(e.sequence + '\n')
+            self.file_pointer.write('+' + e.optional + '\n')
+            self.file_pointer.write(e.qual_scores + '\n')
 
 
 class FastQSource:
@@ -214,8 +220,8 @@ class FastQSource:
         self.pos = 0
         self.forced_raw = False
 
-        self.compressed = compressed or file_path.endswith('.gz')
-        if self.compressed:
+        self.compressed_input = compressed or file_path.endswith('.gz')
+        if self.compressed_input:
             # wrap it with TextIOWrapper to prevent gzip.open to return byte\
             # objects.
             self.file_pointer = io.TextIOWrapper(gzip.open(file_path, 'r'))
